Learn R Programming

spiR (version 0.2.1)

spir_country: spir_country

Description

This function allows you to find and search the right country code associated with the Social Progress Index's Data. If no argument is filed, all indicators will be displayed.

Usage

spir_country(country)

Arguments

country

The name of the country.

Value

Country's ISO code.

See Also

spir_indicator for the SPI's indicators and spir_data to collect data when you have both indicator and country code.

Examples

Run this code
# NOT RUN {
mycountry <- spir_country()
mycountry <- spir_country(country = "Canada")
mycountry <- spir_country("Canada")

# }

Run the code above in your browser using DataLab