This function allows you to find and search the right country code associated with the Social Progress Index's Data.
If no argument is filed, all indicators will be displayed.
Usage
spir_country(country)
Arguments
country
The name of the country.
Value
Country's ISO code.
See Also
spir_indicator for the SPI's indicators and spir_data to collect data when you have both indicator and country code.